@@ -1,28 +1,30 @@
-## ----setup, include=FALSE-----------------------------------------------------
+## ----setup, include=FALSE-------------------------------------------
 knitr::opts_chunk$set(echo = TRUE, cache = FALSE)
+knitr::opts_chunk$set(fig.path="figures/int-design/")
 Design = matrix()
-library(INLA)
 set.seed(123)
+library(INLA)
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
+if (file.exists("myinit.R")) source("myinit.R")
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 	opts = control.inla(int.strategy = "user", int.design = Design)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  	opts = control.inla(int.strategy = "user.std", int.design = Design)
 
-## ---- eval=TRUE, echo=TRUE----------------------------------------------------
+## ----eval=TRUE, echo=TRUE-------------------------------------------
 n = 100
 rho = 0.9
 x = scale(arima.sim(n, model = list(ar = rho)))
 y = x + rnorm(n, sd = 0.1)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 plot(y, xlab = "time", ylab = "value")
 lines(x, lwd=2)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 rho.0 = rho
 to.theta = inla.models()$latent$ar1$hyper$theta2$to.theta
 rho.0.internal = to.theta(rho.0)
@@ -39,16 +41,13 @@ r = inla(y ~ -1 + f(time, model="ar1",
 sd.0 = r$summary.random$time[1,"sd"]
 print(sd.0)
 
-## -----------------------------------------------------------------------------
-nm = names(r$joint.hyper)
-nm = nm[-length(nm)]
-print(nm)
-
-## -----------------------------------------------------------------------------
-Design = as.matrix(cbind(r$joint.hyper[, seq_along(nm)], 1))
+## -------------------------------------------------------------------
+summary(r)
+nm <- nrow(r$summary.hyperpar)
+Design = as.matrix(cbind(r$joint.hyper[, seq_len(nm)], 1))
 head(Design)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 h.rho = 0.01
 rho.1.internal = to.theta(rho.0 + h.rho)
 rr = inla(y ~ -1 + f(time, model="ar1",
@@ -65,14 +64,14 @@ rr = inla(y ~ -1 + f(time, model="ar1",
 sd.1 = rr$summary.random$time[1,"sd"]
 print(sd.1)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 deriv.1 = (sd.1 - sd.0) / h.rho
 print(deriv.1)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  control.inla = list(int.stategy = "user.expert")
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n = 50
 x = rnorm(n)
 y = 1 + x + rnorm(n, sd = 0.2)
